@@ -14,8 +14,6 @@ auto add(int i, int j) {
     return i + j;
 }
 
-PYBIND11_PLUGIN(cpp14module) {
-    pybind11::module m("cpp14module", "auto-compiled c++ extension");
+PYBIND11_MODULE(cpp14module, m) {
     m.def("add", &add);
-    return m.ptr();
 }
